@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Sah::Schema;
 
 our $DATE = '2016-03-08'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -78,8 +78,9 @@ sub weave_section {
     if ($filename =~ m!^lib/(.+)\.pm$!) {
         $package = $1;
         $package =~ s!/!::!g;
-        next unless $package =~ /^Sah::Schema::/;
-        $self->_process_module($document, $input, $package);
+        if ($package =~ /^Sah::Schema::/) {
+            $self->_process_module($document, $input, $package);
+        }
     }
 }
 
@@ -98,7 +99,7 @@ Pod::Weaver::Plugin::Sah::Schema - Plugin to use when building Sah::Schema::* di
 
 =head1 VERSION
 
-This document describes version 0.02 of Pod::Weaver::Plugin::Sah::Schema (from Perl distribution Pod-Weaver-Plugin-Sah-Schema), released on 2016-03-08.
+This document describes version 0.03 of Pod::Weaver::Plugin::Sah::Schema (from Perl distribution Pod-Weaver-Plugin-Sah-Schema), released on 2016-03-08.
 
 =head1 SYNOPSIS
 
